@@ -3,7 +3,7 @@
 # Filename: AutoInit_GBase8s.sh
 # Function: Auto install GBase 8s software and auto init database.
 # Write by: liaojinqing@gbase.cn
-# Version : 1.3.12   update date: 2021-12-02
+# Version : 1.4.0   update date: 2022-01-11
 ##################################################################
 ##### Defind env
 export LANG=C
@@ -105,33 +105,18 @@ if [ -d ${DATADIR} ] && [ ! x"$(ls -A ${DATADIR})" = x ]; then
   DATADIR=${INSTALL_DIR}/data
 fi
 
-ENVCHECK=""
 SOFTPACKNAME=$(ls GBase*.tar 2>/dev/null)
 if [ x"$SOFTPACKNAME" = x ]; then
-  ENVCHECK=${ENVCHECK}" 1) Software not exists.\n"
-fi
-
-if [ -x "/bin/unzip" -o -x "/usr/bin/unzip" ]; then
-  loginfo "unzip check passed."
-else
-  ENVCHECK=${ENVCHECK}" 2) unzip not exists.\n"
-fi
-if [ -x "/bin/tar" -o -x "/usr/bin/tar" ]; then
-  loginfo "tar check passed."
-else
-  ENVCHECK=${ENVCHECK}" 3) tar not exists.\n"
-fi
-if [ -x "/bin/timeout" -o -x "/usr/bin/timeout" ]; then
-  loginfo "timeout check passed."
-else
-  ENVCHECK=${ENVCHECK}" 4) timeout not exists.\n"
-fi
-
-if [ ! x"${ENVCHECK}" = x ]; then
-  echo -e "ERROR found:\n"${ENVCHECK}
+  loginfo "ERROR: ${ENVCHECK} not found."
   exit 2
 fi
 
+### CheckEnv.sh
+bash CheckEnv.sh
+if [ $? -gt 0 ]; then
+    exit 3
+fi
+
 # IP use first IPADDR
 # IPADDR=$(ifconfig -a | awk '/inet /{printf (split($2,a,":")>1)?a[2]:$2" "}')
 loginfo "IPADDR: 0.0.0.0"
@@ -202,6 +187,11 @@ CFG_SHMADD=$(expr ${CFG_SHMVIRTSIZE:-1024000} / 4)
 CFG_SHMTOTAL=$(expr $NUMMEM \* 900)
 
 ##### Create group and user
+id ${USER_NAME} >/dev/null 2>&1
+if [ $? -eq 0 ];then
+    echo "User: ${USER_NAME} exists, you must check !" 
+    exit 2
+fi
 loginfo "Creating group [${USER_NAME}] and user [${USER_NAME}] with HOME [$USER_HOME]."
 groupadd ${USER_NAME} 2>/dev/null
 if [ $? -gt 0 ]; then
@@ -218,9 +208,9 @@ ${USER_PASS}
 ${USER_PASS}
 EOF
 mkdir -p ${USER_HOME}/users 2>/dev/null
-chmod 755 ${USER_HOME} 2>/dev/null
+chmod 0755 ${USER_HOME} 2>/dev/null
 chown ${USER_NAME}:${USER_NAME} ${USER_HOME} 2>/dev/null
-chmod 777 ${USER_HOME}/users 2>/dev/null
+chmod 0777 ${USER_HOME}/users 2>/dev/null
 chown ${USER_NAME}:${USER_NAME} ${USER_HOME}/users 2>/dev/null
 
 ##### Unzip software and install
@@ -243,7 +233,7 @@ fi
 
 mkdir -p $INSTALL_DIR 2>/dev/null
 chown ${USER_NAME}:${USER_NAME} $INSTALL_DIR 2>/dev/null
-chmod 755 $INSTALL_DIR 2>/dev/null
+chmod 0755 $INSTALL_DIR 2>/dev/null
 
 # ids_install
 loginfo "Execute software install, this will take a moment."
@@ -316,7 +306,7 @@ cd $DATADIR
 > rootchk
 touch plogchk llogchk sbspace01 tempchk01 datachk01
 chown ${USER_NAME}:${USER_NAME} rootchk plogchk llogchk sbspace01 tempchk01 datachk01
-chmod 660 rootchk plogchk llogchk sbspace01 tempchk01 datachk01
+chmod 0660 rootchk plogchk llogchk sbspace01 tempchk01 datachk01
 cd $TMPDIR
 
 if [ "x$SOFTONLY" = xy -o "x$SOFTONLY" = xY ];then
@@ -429,12 +419,25 @@ do
   su - ${USER_NAME} -c "onparams -d -l $e -y >/dev/null 2>&1"
 done
 
+### Build default database: testdb
+loginfo "Create database testdb."
+CRDB_SQLFILE=${INSTALL_DIR}/temp/crdb_sqlfile.sql
+mkdir -p ${INSTALL_DIR}/temp
+cat << ! > $CRDB_SQLFILE 2>&1
+create database testdb in datadbs01 with log;
+!
+if [ -s $CRDB_SQLFILE ]; then
+  chown ${USER_NAME}:${USER_NAME} ${INSTALL_DIR}/temp
+  chown ${USER_NAME}:${USER_NAME} $CRDB_SQLFILE
+  su - ${USER_NAME} -c "dbaccess sysmaster $CRDB_SQLFILE >/dev/null 2>&1"
+fi
+
 ###### change config
 loginfo "Creating file \$INSTALL_DIR/etc/sysadmin/stop ."
 if [ ! -f $INSTALL_DIR/etc/sysadmin/stop ]; then
   touch $INSTALL_DIR/etc/sysadmin/stop
   chown ${USER_NAME}:${USER_NAME} $INSTALL_DIR/etc/sysadmin/stop
-  chmod 644 $INSTALL_DIR/etc/sysadmin/stop
+  chmod 0644 $INSTALL_DIR/etc/sysadmin/stop
 fi
 
 ## cfg with static value
@@ -481,22 +484,12 @@ fi
 loginfo "Restart GBase 8s Database Server."
 su - ${USER_NAME} -c "timeout 1800 onmode -ky"
 sleep 5
-su - ${USER_NAME} -c "timeout 1800 oninit -vy"
-
-### Build default database: testdb
-loginfo "Create database testdb."
-CRDB_SQLFILE=${INSTALL_DIR}/temp/crdb_sqlfile.sql
-mkdir -p ${INSTALL_DIR}/temp
-cat << ! > $CRDB_SQLFILE 2>&1
-create database testdb in datadbs01 with log;
-!
-if [ -s $CRDB_SQLFILE ]; then
-  chown ${USER_NAME}:${USER_NAME} ${INSTALL_DIR}/temp
-  chown ${USER_NAME}:${USER_NAME} $CRDB_SQLFILE
-  su - ${USER_NAME} -c "dbaccess sysmaster $CRDB_SQLFILE >/dev/null 2>&1"
+su - ${USER_NAME} -c "oninit -vy"
+if [ $? -eq 0 ]; then
+  loginfo "Finish."
+else
+  loginfo "Restart Server with ERROR. Please reduce the memory parameters(SHMVIRTSIZE,BUFFPOOLS), and then restart the server."
 fi
-
-loginfo "Finish."
 cat <<EOF
 
 --== GBase 8s Information for this install ==--
